@@ -17,7 +17,6 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"html/template"
 	"io"
 	"mime"
 	"net/url"
@@ -95,6 +94,7 @@ type Site struct {
 	language  *langs.Language
 	languagei int
 	pageMap   *pageMap
+	store     *maps.Scratch
 
 	// The owning container.
 	h *HugoSites
@@ -248,6 +248,7 @@ func NewHugoSites(cfg deps.DepsCfg) (*HugoSites, error) {
 			language:           language,
 			languagei:          i,
 			frontmatterHandler: frontmatterHandler,
+			store:              maps.NewScratch(),
 		}
 
 		if i == 0 {
@@ -410,12 +411,6 @@ func newHugoSites(cfg deps.DepsCfg, d *deps.Deps, pageTrees *pageTrees, sites []
 	return h, nil
 }
 
-// Deprecated: Use hugo.IsServer instead.
-func (s *Site) IsServer() bool {
-	hugo.Deprecate(".Site.IsServer", "Use hugo.IsServer instead.", "v0.120.0")
-	return s.conf.Internal.Running
-}
-
 // Returns the server port.
 func (s *Site) ServerPort() int {
 	return s.conf.C.BaseURL.Port()
@@ -430,13 +425,6 @@ func (s *Site) Copyright() string {
 	return s.conf.Copyright
 }
 
-// Deprecated: Use .Site.Home.OutputFormats.Get "rss" instead.
-func (s *Site) RSSLink() template.URL {
-	hugo.Deprecate(".Site.RSSLink", "Use the Output Format's Permalink method instead, e.g. .OutputFormats.Get \"RSS\".Permalink", "v0.114.0")
-	rssOutputFormat := s.home.OutputFormats().Get("rss")
-	return template.URL(rssOutputFormat.Permalink())
-}
-
 func (s *Site) Config() page.SiteConfig {
 	return page.SiteConfig{
 		Privacy:  s.conf.Privacy,
@@ -518,18 +506,6 @@ func (s *Site) Social() map[string]string {
 	return s.conf.Social
 }
 
-// Deprecated: Use .Site.Config.Services.Disqus.Shortname instead.
-func (s *Site) DisqusShortname() string {
-	hugo.Deprecate(".Site.DisqusShortname", "Use .Site.Config.Services.Disqus.Shortname instead.", "v0.120.0")
-	return s.Config().Services.Disqus.Shortname
-}
-
-// Deprecated: Use .Site.Config.Services.GoogleAnalytics.ID instead.
-func (s *Site) GoogleAnalytics() string {
-	hugo.Deprecate(".Site.GoogleAnalytics", "Use .Site.Config.Services.GoogleAnalytics.ID instead.", "v0.120.0")
-	return s.Config().Services.GoogleAnalytics.ID
-}
-
 func (s *Site) Param(key any) (any, error) {
 	return resource.Param(s, nil, key)
 }
@@ -614,6 +590,10 @@ func (s *Site) AllRegularPages() page.Pages {
 	return s.h.RegularPages()
 }
 
+func (s *Site) Store() *maps.Scratch {
+	return s.store
+}
+
 func (s *Site) CheckReady() {
 	if s.state != siteStateReady {
 		panic("this method cannot be called before the site is fully initialized")
